
COLORS={}
# Reset
COLORS["reset"]= "\033[0m"       # Text Reset

# Regular Colors
COLORS["black"]= "\033[0;30m"        # Black
COLORS["red"]= "\033[0;31m"          # Red
COLORS["green"]= "\033[0;32m"        # Green
COLORS["yellow"]= "\033[0;33m"       # Yellow
COLORS["blue"]= "\033[0;34m"         # Blue
COLORS["purple"]= "\033[0;35m"       # Purple
COLORS["cyan"]= "\033[0;36m"         # Cyan
COLORS["white"]= "\033[0;37m"        # White

# Bold
COLORS["boldBlack"]= "\033[1;30m"       # Black
COLORS["boldRed"]= "\033[1;31m"         # Red
COLORS["boldGreen"]= "\033[1;32m"       # Green
COLORS["boldYellow"]= "\033[1;33m"      # Yellow
COLORS["boldBlue"]= "\033[1;34m"        # Blue
COLORS["boldPurple"]= "\033[1;35m"      # Purple
COLORS["boldCyan"]= "\033[1;36m"        # Cyan
COLORS["boldWhite"]= "\033[1;37m"       # White

# Underline
COLORS["underlineBlack"]= "\033[4;30m"       # Black
COLORS["underlineRed"]= "\033[4;31m"         # Red
COLORS["underlineGreen"]= "\033[4;32m"       # Green
COLORS["underlineYellow"]= "\033[4;33m"      # Yellow
COLORS["underlineBlue"]= "\033[4;34m"        # Blue
COLORS["underlinePurple"]= "\033[4;35m"      # Purple
COLORS["underlineCyan"]= "\033[4;36m"        # Cyan
COLORS["underlineWhite"]= "\033[4;37m"       # White

# Background
COLORS["backgroundBlack"]= "\033[40m"       # Black
COLORS["backgroundRed"]= "\033[41m"         # Red
COLORS["backgroundGreen"]= "\033[42m"       # Green
COLORS["backgroundYellow"]= "\033[43m"      # Yellow
COLORS["backgroundBlue"]= "\033[44m"        # Blue
COLORS["backgroundPurple"]= "\033[45m"      # Purple
COLORS["backgroundCyan"]= "\033[46m"        # Cyan
COLORS["backgroundWhite"]= "\033[47m"       # White

# High Intensity
COLORS["intenseBlack"]= "\033[0;90m"       # Black
COLORS["intenseRed"]= "\033[0;91m"         # Red
COLORS["intenseGreen"]= "\033[0;92m"       # Green
COLORS["intenseYellow"]= "\033[0;93m"      # Yellow
COLORS["intenseBlue"]= "\033[0;94m"        # Blue
COLORS["intensePurple"]= "\033[0;95m"      # Purple
COLORS["intenseCyan"]= "\033[0;96m"        # Cyan
COLORS["intenseWhite"]= "\033[0;97m"       # White

# Bold High Intensity
COLORS["intenseBoldBlack"]= "\033[1;90m"      # Black
COLORS["intenseBoldRed"]= "\033[1;91m"        # Red
COLORS["intenseBoldGreen"]= "\033[1;92m"      # Green
COLORS["intenseBoldYellow"]= "\033[1;93m"     # Yellow
COLORS["intenseBoldBlue"]= "\033[1;94m"       # Blue
COLORS["intenseBoldPurple"]= "\033[1;95m"     # Purple
COLORS["intenseBoldCyan"]= "\033[1;96m"       # Cyan
COLORS["intenseBoldWhite"]= "\033[1;97m"      # White

# High Intensity backgrounds
COLORS["intenseBackgroundBlack"]= "\033[0;100m"   # Black
COLORS["intenseBackgroundRed"]= "\033[0;101m"     # Red
COLORS["intenseBackgroundGreen"]= "\033[0;102m"   # Green
COLORS["intenseBackgroundYellow"]= "\033[0;103m"  # Yellow
COLORS["intenseBackgroundBlue"]= "\033[0;104m"    # Blue
COLORS["intenseBackgroundPurple"]= "\033[0;105m"  # Purple
COLORS["intenseBackgroundCyan"]= "\033[0;106m"    # Cyan
COLORS["intenseBackgroundWhite"]= "\033[0;107m"   # White


from __future__ import print_function

from swag import colors

#
#   Modifier
#

BOLD = "bold"
UNDERLINE = "underline"
BACKGROUND = "background"

INTENSE = "intense"
INTENSE_BOLD = "intenseBold"
INTENSE_BACKGROUND = "intenseBackground"


def _print_swaggy(color, content, modifier=None, continous=False):
    if modifier is not None:
        color = modifier + color.title()
    text = "{0}{1}".format(color, content) \
        if continous else "{0}{1}{2}".format(color, content, colors.COLORS["reset"])

    print(text)


def print_black(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["black"], content, modifier, continous)


def print_yellow(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["yellow"], content, modifier, continous)


def print_green(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["green"], content, modifier, continous)


def print_red(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["red"], content, modifier, continous)


def print_blue(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["blue"], content, modifier, continous)


def print_purple(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["purple"], content, modifier, continous)


def print_white(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["white"], content, modifier, continous)


def print_cyan(content, modifier=None, continous=False):
    _print_swaggy(colors.COLORS["cyan"], content, modifier, continous)


def reset():
    print(colors.COLORS["reset"])



# -*- coding: UTF-8 -*-
from __future__ import print_function
import os

from swag import colors


def install(dest="default"):
    if dest == "default":
        directory = os.path.expanduser("~") + "/.colors"
    else:
        directory = dest

    colorDictionary = colors.COLORS

    if not os.path.exists(directory):
        os.makedirs(directory)

    for i, key in enumerate(colorDictionary):
        print(
            colors.COLORS["reset"] + colors.COLORS[key] + "Installed " + directory + "/" + key + colors.COLORS["reset"])
        file = open(directory + "/" + key, "w")
        file.write(colorDictionary[key])
        file.close()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['swag']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'swag',
    'version': '1.6.1',
    'description': 'Swag up your shell output with escape code magic!',
    'long_description': None,
    'author': '4thel00z',
    'author_email': '4thel00z@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)



#! env python
# -*- coding: UTF-8 -*-
from __future__ import print_function
import os

import argparse

from swag import colors



directory = os.path.expanduser("~") + "/.colors"

parser = argparse.ArgumentParser()

subParsers = parser.add_subparsers(help='[command] help')

installParser = subParsers.add_parser("install",
                                      help="install the colors to the folder of choice")

installParser.add_argument_group()
installParser.add_argument("-d", "--dest", default="default",
                           help="default = ~/.colors - install the color escape sequences to the specified destination")

installParser.add_argument("-l", "--list", default=False, action="store_true")

printParser = subParsers.add_parser("print",
                                    help="prints the text with the specified color and type to the console")

printParser.add_argument_group()
printParser.add_argument("-c", "--color", default="white",
                         help="default = white - which color to format the text in : black|red|green|yellow|blue|purple|cyan|white")

printParser.add_argument("-t", "--type", default="normal",
                         help="default = normal - format the string with either: normal|underline|background|bold|intense|intenseBold|intenseBackground")

printParser.add_argument("text", type=str, default="", help="the text to swag up")


def getKey(color, type):
    if type is "normal":
        if color.lower() in "black|red|green|yellow|blue|purple|cyan|white".split("|"):
            return color
        else:
            return "white"

    elif type.lower() in "underline|background|bold|intense|intenseBold|intenseBackground":
        if color.lower() in "black|red|green|yellow|blue|purple|cyan|white".split("|"):
            return type.lower() + color.lower().capitalize()
        else:
            return type.lower() + "White"
    else:
        return "white"


def install(dest):
    from swag import createFolders
    createFolders.install(dest)


def list():
    colorDictionary = colors.COLORS
    for i, key in enumerate(colorDictionary):
        print (colors.COLORS["reset"] + colors.COLORS[key] + key + colors.COLORS["reset"])


def main():
    args = parser.parse_args()

    if "dest" in args:
        dest = args.dest
        if not args.list:
            install(dest)
        else:
            list()
    else:
        color = args.color
        type = args.type
        text = args.text
        key = getKey(color, type)
        colorMod = colors.COLORS[key]
        print(colorMod + text)


if __name__ == '__main__':
    main()
